@@ -81,6 +81,19 @@ alter table test_settings set (timescaledb.compress,
     timescaledb.compress_orderby = 'x',
     timescaledb.compress_index = 'bloom("u"), minmax("u")');
 
+-- multiple columns
+alter table test_settings set (timescaledb.compress,
+    timescaledb.compress_orderby = 'x',
+    timescaledb.compress_index = 'bloom("u,ts")');
+
+alter table test_settings set (timescaledb.compress,
+    timescaledb.compress_orderby = 'x',
+    timescaledb.compress_index = 'bloom(u,ts)');
+
+alter table test_settings set (timescaledb.compress,
+    timescaledb.compress_orderby = 'x',
+    timescaledb.compress_index = 'bloom(u,abc)');
+
 -- duplicate column
 alter table test_settings set (timescaledb.compress,
     timescaledb.compress_orderby = 'x',
@@ -178,11 +191,11 @@ select schema_name || '.' || table_name chunk from _timescaledb_catalog.chunk
 \d+ :chunk
 
 -- UUID uses bloom
-explain (analyze, verbose, costs off, timing off, summary off)
+explain (analyze, verbose, buffers off, costs off, timing off, summary off)
 select count(*) from test_sparse_index where u = '90ec9e8e-4501-4232-9d03-6d7cf6132815';
 
 -- Timestamp uses minmax
-explain (analyze, verbose, costs off, timing off, summary off)
+explain (analyze, verbose, buffers off, costs off, timing off, summary off)
 select count(*) from test_sparse_index where ts between '2021-01-07' and '2021-01-14';
 
 drop table test_sparse_index;
@@ -215,13 +228,22 @@ select schema_name || '.' || table_name chunk from _timescaledb_catalog.chunk
 
 -- these tests show that despite column having multiple sparse indexes, the appropriate one is selected by the planner
 -- UUID uses bloom
-explain (analyze, verbose, costs off, timing off, summary off)
+explain (analyze, verbose, buffers off, costs off, timing off, summary off)
 select count(*) from test_sparse_index where u = '90ec9e8e-4501-4232-9d03-6d7cf6132815';
 
 -- Timestamp uses minmax
-explain (analyze, verbose, costs off, timing off, summary off)
+explain (analyze, verbose, buffers off, costs off, timing off, summary off)
 select count(*) from test_sparse_index where ts between '2021-01-07' and '2021-01-14';
 
+
+-- Test recompression when the bloom filter index is disabled by a GUC
+set timescaledb.enable_sparse_index_bloom to off;
+
+select count(compress_chunk(decompress_chunk(x))) from show_chunks('test_sparse_index') x;
+
+reset timescaledb.enable_sparse_index_bloom;
+
+
 -- Test rename column
 -- change a non-sparse index column
 alter table test_sparse_index rename value to value_new;
